@@ -78,6 +78,12 @@ function(x, control = list())
 {
     stopifnot(is.list(control))
 
+    if (any(unlist(lapply(control, is.function))))
+        warning("custom functions are ignored")
+
+    if (!is.null(control$tokenize) && !identical(control$tokenize, "Boost"))
+        warning("custom tokenizer is ignored")
+
     txt <- content(x)
 
     ## Conversion to lower case
@@ -171,6 +177,10 @@ function(x, control = list())
     .TermDocumentMatrix(m, control$weighting)
 }
 
+TermDocumentMatrix.default <-
+function(x, control = list())
+    TermDocumentMatrix(Corpus(VectorSource(x)), control)
+
 DocumentTermMatrix <-
 function(x, control = list())
     t(TermDocumentMatrix(x, control))
