@@ -23,7 +23,7 @@ static int is_ascii_space_or_punct(int c) {
     return strchr(s, c) == NULL ? 0 : 1;
 }
 
-static SEXP tm_scan_one(SEXP this, int (*test) ()) {
+static SEXP tm_scan_one(SEXP this, int (*test) (int)) {
     SEXP y;
     Rboolean skip;
     int size = 256, i, j, nb = 0, ne = 0, u, v, w;
@@ -36,8 +36,8 @@ static SEXP tm_scan_one(SEXP this, int (*test) ()) {
 	return ScalarString(NA_STRING);
     }
 
-    beg = Calloc(size, int);
-    end = Calloc(size, int);
+    beg = R_Calloc(size, int);
+    end = R_Calloc(size, int);
 
     e = getCharCE(this);
     s = CHAR(this);
@@ -50,8 +50,8 @@ static SEXP tm_scan_one(SEXP this, int (*test) ()) {
 		if(size > INT_MAX / 2)
 		    error("too many items");
 		size *= 2;
-		beg = Realloc(beg, size, int);
-		end = Realloc(end, size, int);
+		beg = R_Realloc(beg, size, int);
+		end = R_Realloc(end, size, int);
 	    }
 	    beg[nb] = i;
 	    nb++;
@@ -82,8 +82,8 @@ static SEXP tm_scan_one(SEXP this, int (*test) ()) {
 	SET_STRING_ELT(y, i, mkCharCE(p, e));
     }
 
-    Free(beg);
-    Free(end);
+    R_Free(beg);
+    R_Free(end);
 
     UNPROTECT(1);
 
@@ -97,7 +97,7 @@ SEXP _tm_scan(SEXP x, SEXP which) {
     R_xlen_t i, j, k, nx, ny;
     int w;
 
-    int (*test) () = is_ascii_space;
+    int (*test) (int) = is_ascii_space;
 
     if(LENGTH(which) > 0) {
 	PROTECT(this = AS_INTEGER(which));
